@@ -39,7 +39,17 @@ import sys
 import traceback
 try:
     from urllib.error import URLError
+    from urllib.request import build_opener
+    from urllib.request import HTTPBasicAuthHandler
+    from urllib.request import HTTPHandler
+    from urllib.request import install_opener
+    from urllib.request import ProxyHandler
 except ImportError:
+    from urllib2 import build_opener
+    from urllib2 import HTTPBasicAuthHandler
+    from urllib2 import HTTPHandler
+    from urllib2 import install_opener
+    from urllib2 import ProxyHandler
     from urllib2 import URLError
 import warnings
 
@@ -206,7 +216,42 @@ ERROR: your rosdep installation has not been initialized yet.  Please run:
         sys.exit(1)
     else:
         return True
-    
+
+
+def key_list_to_dict(key_list):
+    """
+    Convert a list of strings of the form 'foo:bar' to a dictionary.
+
+    Splits strings of the form 'foo:bar quux:quax' into separate entries.
+    """
+    try:
+        key_list = [key for s in key_list for key in s.split(' ')]
+        return dict(map(lambda s: [t.strip() for t in s.split(':')], key_list))
+    except ValueError as e:
+        raise UsageError("Invalid 'key:value' list: '%s'" % ' '.join(key_list))
+
+
+def str_to_bool(s):
+    """Maps a string to bool. Supports true/false, and yes/no, and is case-insensitive"""
+    s = s.lower()
+    if s in ['yes', 'true']:
+        return True
+    elif s in ['no', 'false']:
+        return False
+    else:
+        raise UsageError("Cannot parse '%s' as boolean" % s)
+
+
+def setup_proxy_opener():
+    # check for http[s]?_proxy user
+    for scheme in ['http', 'https']:
+        key = scheme + '_proxy'
+        if key in os.environ:
+            proxy = ProxyHandler({scheme: os.environ[key]})
+            auth = HTTPBasicAuthHandler()
+            opener = build_opener(proxy, auth, HTTPHandler)
+            install_opener(opener)
+
 def _rosdep_main(args):
     # sources cache dir is our local database.  
     default_sources_cache = get_sources_cache_dir()
@@ -228,6 +273,8 @@ def _rosdep_main(args):
                       action="store_true", help="Simulate install")
     parser.add_option("-r", dest="robust", default=False, 
                       action="store_true", help="Continue installing despite errors.")
+    parser.add_option("-q", dest="quiet", default=False, 
+                      action="store_true", help="Suprress output except for errors")
     parser.add_option("-a", "--all", dest="rosdep_all", default=False, 
                       action="store_true", help="select all packages")
     parser.add_option("-n", dest="recursive", default=True, 
@@ -259,6 +306,11 @@ def _rosdep_main(args):
                       help="Explicitly sets the ROS distro to use, overriding "
                            "the normal method of detecting the ROS distro "
                            "using the ROS_DISTRO environment variable.")
+    parser.add_option("--as-root", default=[], action='append',
+                      metavar="INSTALLER_KEY:<bool>", help="Override "
+                      "whether sudo is used for a specific installer, "
+                      "e.g. '--as-root pip:false' or '--as-root \"pip:no homebrew:yes\"'. "
+                      "Can be specified multiple times.")
 
     options, args = parser.parse_args(args)
     if options.print_version:
@@ -278,8 +330,13 @@ def _rosdep_main(args):
     if options.ros_distro:
         os.environ['ROS_DISTRO'] = options.ros_distro
 
+    # Convert list of keys to dictionary
+    options.as_root = dict((k, str_to_bool(v)) for k, v in key_list_to_dict(options.as_root).items())
+
     if not command in ['init', 'update']:
         check_for_sources_list_init(options.sources_cache_dir)
+    else:
+        setup_proxy_opener()
     if command in _command_rosdep_args:
         return _rosdep_args_handler(command, parser, options, args)
     elif command in _command_no_args:
@@ -394,15 +451,23 @@ def convert_os_override_option(options_os_override):
     os_version = val[val.find(':')+1:]
     return os_name, os_version
     
-def configure_installer_context_os(installer_context, options):
+def configure_installer_context(installer_context, options):
     """
-    Override the OS detector in *installer_context* if necessary.
+    Configure the *installer_context* from *options*.
+
+    - Override the OS detector in *installer_context* if necessary.
+    - Set *as_root* for installers if specified.
 
     :raises: :exc:`UsageError` If user input options incorrectly
     """
     os_override = convert_os_override_option(options.os_override)
     if os_override is not None:
         installer_context.set_os_override(*os_override)
+    for k,v in options.as_root.items():
+        try:
+            installer_context.get_installer(k).as_root = v
+        except KeyError:
+            raise UsageError("Installer '%s' not defined." % k)
     
 def command_init(options):
     try:
@@ -498,7 +563,7 @@ def command_check(lookup, packages, options):
     verbose = options.verbose
     
     installer_context = create_default_installer_context(verbose=verbose)
-    configure_installer_context_os(installer_context, options)
+    configure_installer_context(installer_context, options)
     installer = RosdepInstaller(installer_context, lookup)
 
     uninstalled, errors = installer.get_uninstalled(packages, implicit=options.recursive, verbose=verbose)
@@ -535,11 +600,11 @@ def command_install(lookup, packages, options):
     # map options
     install_options = dict(interactive=not options.default_yes, verbose=options.verbose,
                            reinstall=options.reinstall,
-                           continue_on_error=options.robust, simulate=options.simulate)
+                           continue_on_error=options.robust, simulate=options.simulate, quiet=options.quiet)
 
     # setup installer
     installer_context = create_default_installer_context(verbose=options.verbose)
-    configure_installer_context_os(installer_context, options)
+    configure_installer_context(installer_context, options)
     installer = RosdepInstaller(installer_context, lookup)
 
     if options.reinstall:
@@ -594,7 +659,7 @@ def command_db(options):
     # exact same setup logic as command_resolve, should possibly combine
     lookup = _get_default_RosdepLookup(options)
     installer_context = create_default_installer_context(verbose=options.verbose)
-    configure_installer_context_os(installer_context, options)
+    configure_installer_context(installer_context, options)
     os_name, os_version = installer_context.get_os_name_and_version()
     try:
         installer_keys = installer_context.get_os_installer_keys(os_name)
@@ -660,7 +725,7 @@ def command_where_defined(args, options):
 def command_resolve(args, options):
     lookup = _get_default_RosdepLookup(options)
     installer_context = create_default_installer_context(verbose=options.verbose)
-    configure_installer_context_os(installer_context, options)
+    configure_installer_context(installer_context, options)
 
     installer, installer_keys, default_key, \
             os_name, os_version = get_default_installer(installer_context=installer_context,
